@@ -12,10 +12,10 @@ setClass("msSurv",representation(tree="graphNEL",
                                  nt.states="character",
                                  dNs="array",
                                  Ys="array",
-                                 sum.dNs="array",
+                                 sum_dNs="array",
                                  dNs.K="array",
                                  Ys.K="array",
-                                 sum.dNs.K="array",
+                                 sum_dNs.K="array",
                                  ps="array",
                                  AJs="array",
 				 I.dA="array",
